%define	with_python_version	2.5
%define with_apidocs            1
%define rpmhome /usr/lib/rpm


Distribution:	CCux
Packager:  	Christian Metzen <metzench@ccux-linux.de>

Summary:   	The RPM package management system.
Name:      	rpm
Version:   	4.4.2.3
Release:   	2
License: 	GNU/GPL
URL:		http://www.rpm.org
Group:     	System/Configuration/Packaging
Source0: 	rpm-%{version}.tar.gz
# XXX temporary
Source2: 	find-debuginfo.sh
Patch1: 	rpm-4.4.1-prereq.patch
Patch2: 	rpm-4.4.2-ghost-conflicts.patch
Patch3: 	rpm-4.4.2-trust.patch
Patch4: 	rpm-4.4.2-devel-autodep.patch
Patch5: 	rpm-4.4.2-rpmfc-skip.patch
Patch7: 	rpm-4.4.2.1-no-popt.patch
Patch13: 	rpm-4.4.2.2-nss.patch
Patch14: 	rpm-4.4.2.2-base64-unsigned-char.patch
Patch15: 	rpm-4.4.2.2-cryptoinit.patch
# this is the future lzma patch, use as soon as lzma 4.42 is
# stabilized  - this patch is the OpenSuse way
# alternatively zlib gets lzma support
Patch16:	rpm-4.4.2.3-lzma-payload-support.patch
# this is the PLD way to integrate (current) lzma
# support, disable as soon as lzma 4.42 is stabilized
Patch17:	rpm-4.4.2.2-lzma-support.patch


#CCux Patches
# set CCux defaults
# w2.lzdio now default compression algo
Patch70:	rpm-4.4.2.2-ccux.patch
Patch71: 	rpm-4.3-optional.patch
# set buildflags, remove -g 
Patch72:	rpm-4.4.2.3-optflags.patch

BuildRoot: 	%{_tmppath}/%{name}-buildroot
# XXX for autoreconf due to popt removal
BuildRequires: 	autoconf automake libtool
BuildRequires:	zlib-devel bzip2-devel elfutils-devel beecrypt-devel readline-devel lzma-alpha-devel
BuildRequires:	python-devel sqlite-devel libtool-devel e2fsprogs-devel
BuildRequires:	nss-devel popt-devel popt-static gettext-devel ncurses-devel nspr-devel
BuildConflicts: neon-devel
Requires:	beecrypt popt >= 1.10.2 neon nss nspr
Requires:	lzma-alpha
Provides:	librpm-4.4.so librpmdb-4.4.so librpmio-4.4.so librpmbuild-4.4.so

Provides:       rpmlib(PayloadIsLzma) = 4.4.2-1

%description
The RPM Package Manager (RPM) is a powerful command line driven
package management system capable of installing, uninstalling,
verifying, querying, and updating software packages. Each software
package consists of an archive of files along with information about
the package like its version, a description, etc.

%package devel
Summary: 	Development files for manipulating RPM packages.
Group: 		System/Configuration/Packaging
Requires: 	rpm = %{version}-%{release} popt >= 1.12

%description devel
This package contains the RPM C library and header files. These
development files will simplify the process of writing programs that
manipulate RPM packages and databases. These files are intended to
simplify the process of creating graphical package managers or any
other tools that need an intimate knowledge of RPM packages in order
to function.

This package should be installed if you want to develop programs that
will manipulate RPM packages and databases.

%package build
Summary: 	Scripts and executable programs used to build packages.
Group: 		Development/Tools
Requires: 	rpm = %{version}-%{release}
Provides: 	perl(Specfile)

%description build
The rpm-build package contains the scripts and executable programs
that are used to build packages using the RPM Package Manager.

%package python
Summary: 	Python bindings for apps which will manipulate RPM packages.
Group: 		Development/Libraries
Requires: 	rpm = %{version}-%{release}
Requires: 	python >= %{with_python_version}
Requires: 	elfutils >= 0.55

%description python
The rpm-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by RPM Package Manager libraries.

This package should be installed if you want to develop Python
programs that will manipulate RPM packages and databases.

%if %{with_apidocs}
%package apidocs
Summary: API documentation for RPM libraries
Group: Documentation
BuildRequires: doxygen

%description apidocs
This package contains API documentation for developing applications
that will manipulate RPM packages and databases.
%endif

%post
if [ $1 -eq 2 ]; then
    rpm -q base-config &>/dev/null || :
fi

# XXX Detect (and remove) incompatible dbenv files during upgrade.
# XXX Removing dbenv files in %%post opens a lock race window, a tolerable
# XXX risk compared to the support issues involved with upgrading Berkeley DB.
[ -w /var/lib/rpm/__db.001 ] &&
/usr/lib/rpm/rpmdb_stat -CA -h /var/lib/rpm 2>&1 |
grep "db_stat: Program version ... doesn't match environment version" 2>&1 > /dev/null &&
        rm -f /var/lib/rpm/__db*
                                                                                
exit 0

%prep

# check playload compression algorithm
# we need bz2 compression for compatibility reasons

if ( [ `grep -e "_source_payload" /usr/lib/rpm/macros | cut -f 2 -d "." ` == "lzdio" ] || [ `grep -e "_binary_payload" /usr/lib/rpm/macros | cut -f 2 -d "." ` == "lzdio" ]  ); then
        echo  "This package must be compressed with bz2, please adjust your /usr/lib/macro file accordingly ! "
        exit 1
fi

%setup -q
%patch1 -p1 -b .prereq
%patch2 -p1 -b .ghostconflicts
%patch3 -p1 -b .trust
%patch4 -p1 -b .develdeps
%patch5 -p1 -b .fcskip
%patch7 -p1 -b .no-popt
%patch13 -p1 -b .nss
%patch14 -p1 -b .base64
%patch15 -p1 -b .nss-init
%patch16 -p1 -b .lzma 
#%patch17 -p1 -b .oldlzma
%patch70 -p1
%patch71 -p1
%patch72 -p1

# force external popt
rm -rf popt/

# XXX for popt removal 
./autogen.sh --noconfigure

# new buildid-aware debuginfo 
cp -f %{SOURCE2} scripts/find-debuginfo.sh

%build
# XXX pull in updated config.guess and config.sub as done by %%configure
# which cannot be used to build rpm itself due to makefile brokenness
#for i in $(find . -name config.guess -o -name config.sub) ; do 
#    [ -f /usr/lib/rpm/$(basename $i) ] && %{__rm} -f $i && %{__cp} -fv /usr/lib/rpm/$(basename $i) $i 
#done 

export CFLAGS="$RPM_OPT_FLAGS"
./configure --prefix=%_prefix --sysconfdir=%_sysconfdir --localstatedir=/var \
    -mandir=%_mandir --infodir=%_infodir --without-selinux --disable-selinux --with-selinux=no \
    --enable-posixmutexes --with-python=%{with_python_version}

pushd file/src
make %{?_smp_mflags}
popd

pushd db3
make %{?_smp_mflags}
popd

make LIBTOOL=/usr/bin/libtool %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

# Clean up dangling symlinks
# XXX Fix in rpm tree
for i in /usr/bin/rpme /usr/bin/rpmi /usr/bin/rpmu; do
    rm -f "$RPM_BUILD_ROOT"/"$i" 
done

# Save list of packages through cron
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/cron.daily
install -m 755 scripts/rpm.daily ${RPM_BUILD_ROOT}%{_sysconfdir}/cron.daily/rpm

mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d
install -m 644 scripts/rpm.log ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/rpm

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/rpm

mkdir -p $RPM_BUILD_ROOT/var/spool/repackage
mkdir -p $RPM_BUILD_ROOT/var/lib/rpm
for dbi in \
        Basenames Conflictname Dirnames Group Installtid Name Packages \
        Providename Provideversion Requirename Requireversion Triggername \
        Filemd5s Pubkeys Sha1header Sigmd5 \
        __db.001 __db.002 __db.003 __db.004 __db.005 __db.006 __db.007 \
        __db.008 __db.009
do
    touch $RPM_BUILD_ROOT/var/lib/rpm/$dbi
done

%find_lang %{name}

# copy db and file/libmagic license info to distinct names
cp -p db/LICENSE LICENSE-bdb
cp -p file/LEGAL.NOTICE LEGAL.NOTICE-file
cp -p lua/COPYRIGHT COPYRIGHT-lua

# Get rid of unpackaged files
{ cd $RPM_BUILD_ROOT
  rm -f .%{_libdir}/lib*.a
  rm -f .%{rpmhome}/{Specfile.pm,cpanflute,cpanflute2,rpmdiff,rpmdiff.cgi,sql.prov,sql.req,tcl.req,rpm.*}
  rm -rf .%{_mandir}/{fr,ko}
  rm -f .%{_libdir}/python%{with_python_version}/site-packages/*.{a,la}
  rm -f .%{_libdir}/python%{with_python_version}/site-packages/rpm/*.{a,la}
  rm -f .%{_libdir}/python%{with_python_version}/site-packages/rpmdb/*.{a,la}
}

find $RPM_BUILD_ROOT/%{_libdir}/python%{with_python_version} -name "*.py"|xargs chmod 644

%define rpmattr   %attr(0755, root, root)
%define rpmdbattr %attr(0644, root, root) %verify(not md5 size mtime) %ghost %config(missingok,noreplace)

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc CHANGES GROUPS COPYING LICENSE-bdb LEGAL.NOTICE-file CREDITS ChangeLog
%doc COPYRIGHT-lua doc/manual/[a-z]*
%{_sysconfdir}/cron.daily/rpm
%config(noreplace,missingok)    %{_sysconfdir}/logrotate.d/rpm
%dir                            %{_sysconfdir}/rpm
%attr(0755, root, root)   %dir /var/lib/rpm
%rpmdbattr /var/lib/rpm/*
%attr(0755, root, root) %dir /var/spool/repackage
%attr(0755, root, root) %dir %{rpmhome}
%{rpmattr} /bin/rpm
%{rpmattr} %{_bindir}/rpm2cpio
%{rpmattr} %{_bindir}/gendiff
%{rpmattr} %{_bindir}/rpmdb
%{rpmattr} %{_bindir}/rpmsign
%{rpmattr} %{_bindir}/rpmquery
%{rpmattr} %{_bindir}/rpmverify
%{rpmattr} %{rpmhome}/config.guess
%{rpmattr} %{rpmhome}/config.sub
%{rpmattr} %{rpmhome}/convertrpmrc.sh
%{rpmattr} %{rpmhome}/freshen.sh
%{rpmattr} %{rpmhome}/mkinstalldirs
%{rpmattr} %{rpmhome}/rpm2cpio.sh
%{rpmattr} %{rpmhome}/rpm[deiukqv]
%{rpmattr} %{rpmhome}/tgpg
%{rpmattr} %{rpmhome}/rpmdb_*
%{rpmattr} %{rpmhome}/rpmfile
%attr(0644, root, root) %{rpmhome}/macros
%attr(0644, root, root) %{rpmhome}/rpmpopt*
%attr(0644, root, root) %{rpmhome}/rpmrc
%attr(-, root, root) %{rpmhome}/i[3456]86*
%attr(-, root, root) %{rpmhome}/athlon*
%attr(-, root, root) %{rpmhome}/geode*
%attr(-, root, root) %{rpmhome}/pentium*
%attr(-, root, root) %{rpmhome}/noarch*
%{_mandir}/man1/gendiff.1*
%{_mandir}/man8/rpm.8*
%{_mandir}/man8/rpm2cpio.8*
# XXX this places translated manuals to wrong package wrt eg rpmbuild
%lang(ja) %{_mandir}/ja/man[18]/*.[18]*
%lang(pl) %{_mandir}/pl/man[18]/*.[18]*
%lang(ru) %{_mandir}/ru/man[18]/*.[18]*
%lang(sk) %{_mandir}/sk/man[18]/*.[18]*
%{_libdir}/librpm*-*.so

%files build
%defattr(-,root,root)
%attr(0777, root, root) %{_usrsrc}/ccux
%{rpmattr} %{_bindir}/rpmbuild
%{rpmattr} %{rpmhome}/brp-*
%{rpmattr} %{rpmhome}/check-buildroot
%{rpmattr} %{rpmhome}/check-files
%{rpmattr} %{rpmhome}/check-prereqs
%{rpmattr} %{rpmhome}/check-rpaths*
%{rpmattr} %{rpmhome}/cross-build
%{rpmattr} %{rpmhome}/debugedit
%{rpmattr} %{rpmhome}/find-debuginfo.sh
%{rpmattr} %{rpmhome}/find-lang.sh
%{rpmattr} %{rpmhome}/find-prov.pl
%{rpmattr} %{rpmhome}/find-provides
%{rpmattr} %{rpmhome}/find-provides.perl
%{rpmattr} %{rpmhome}/find-req.pl
%{rpmattr} %{rpmhome}/find-requires
%{rpmattr} %{rpmhome}/find-requires.perl
%{rpmattr} %{rpmhome}/get_magic.pl
%{rpmattr} %{rpmhome}/getpo.sh
%{rpmattr} %{rpmhome}/http.req
%{rpmattr} %{rpmhome}/javadeps
%{rpmattr} %{rpmhome}/magic.prov
%{rpmattr} %{rpmhome}/magic.req
%{rpmattr} %{rpmhome}/mono-find-provides
%{rpmattr} %{rpmhome}/mono-find-requires
%{rpmattr} %{rpmhome}/osgideps.pl
%{rpmattr} %{rpmhome}/perldeps.pl
%{rpmattr} %{rpmhome}/perl.prov
%{rpmattr} %{rpmhome}/perl.req
%{rpmattr} %{rpmhome}/pythondeps.sh
%{rpmattr} %{rpmhome}/rpm[bt]
%{rpmattr} %{rpmhome}/rpmdeps
%{rpmattr} %{rpmhome}/trpm
%{rpmattr} %{rpmhome}/u_pkg.sh
%{rpmattr} %{rpmhome}/vpkg-provides.sh
%{rpmattr} %{rpmhome}/vpkg-provides2.sh
%attr(0644, root, root) %{rpmhome}/config.site
%attr(0644, root, root) %{rpmhome}/magic
%attr(0644, root, root) %{rpmhome}/magic.mgc
%attr(0644, root, root) %{rpmhome}/magic.mime
%attr(0644, root, root) %{rpmhome}/magic.mime.mgc
%{_mandir}/man8/rpmbuild.8*
%{_mandir}/man8/rpmdeps.8*

%files python
%defattr(-,root,root)
%{_libdir}/python%{with_python_version}/site-packages/rpm

%files devel
%defattr(-,root,root)
%{_includedir}/rpm
%{_libdir}/librp*[a-z].so
%{_libdir}/librp*[a-z].la
%{_mandir}/man8/rpmcache.8*
%{_mandir}/man8/rpmgraph.8*
%{rpmattr} %{rpmhome}/rpmcache
%{rpmattr} %{_bindir}/rpmgraph

%if %{with_apidocs}
%files apidocs
%defattr(-,root,root)
%doc apidocs
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Sun May 18 2008 Karsten Brockmann <arcam@ccux-linux.de> 4.4.2.3-2
- added Provides rpmlib(PayloadIsLzma) for clean lzma upgrade path
* Sun May 18 2008 Karsten Brockmann <arcam@ccux-linux.de> 4.4.2.3-1
- Version update
- added support for lzma compressed payloads
- default payload compression is now lzma
* Thu Jan 31 2008 Christian Metzen <metzench@ccux-linux.de> 4.4.2.2-7
- get rid of -g optflag
* Fri Nov 30 2007 Christian Metzen <metzench@ccux-linux.de> 4.4.2.2-6
- fixed nspr require, seems not to be autoresolved
* Sat Nov 24 2007 Christian Metzen <metzench@ccux-linux.de> 4.4.2.2-5
- removed rpm user / group
* Fri Nov 23 2007 Christian Metzen <metzench@ccux-linux.de> 4.4.2.2-4
- added optflags patch
* Fri Nov 23 2007 Christian Metzen <metzench@ccux-linux.de> 4.4.2.2-3
- fixed permissions for /usr/src/ccux
* Fri Nov 23 2007 Christian Metzen <metzench@ccux-linux.de> 4.4.2.2-2
- Bugfix in user addition
* Fri Nov 23 2007 Christian Metzen <metzench@ccux-linux.de> 4.4.2.2-1
- Version update, separated popd package
* Wed Sep 20 2006 Karsten Brockmann <arcam@ccux-linux.de> 4.4.2-6
- rebuilt against python 2.5
* Fri Apr 21 2006 Christian Metzen <metzench@ccux-linux.de> 4.4.2-5
- changed default compression to bz2 again, saves space, cleaned spec
* Wed Apr 12 2006 Christian Metzen <metzench@ccux-linux.de> 4.4.2-4
- fixed devel package require
* Wed Apr 12 2006 Christian Metzen <metzench@ccux-linux.de> 4.4.2-3
- fixed minor bug, aded changelog
* Wed Apr 12 2006 Christian Metzen <metzench@ccux-linux.de> 4.4.2-2
- fixed minor bug
* Wed Apr 12 2006 Christian Metzen <metzench@ccux-linux.de> 4.4.2-1
- Version update, fixed minor bug
* Wed Nov 09 2005 Christian Metzen <metzench@ccux-linux.de> 4.4.1-8
- Added more RPM Macros
* Wed Sep 14 2005 Christian Metzen <metzench@ccux-linux.de> 4.4.1-7
- Removed now obsolete Apt Patch, fixed minor Bug
* Wed Jul 20 2005 Christian Metzen <metzench@ccux-linux.de> 4.4.1-6
- Added Python Modules
* Sat Jul 09 2005 Christian Metzen <metzench@ccux-linux.de> 4.4.1-5
- removed sqllite dependecy
* Fri Jul 08 2005 Karsten Brockmkann <brockmka@rz.fh-augsburg.de> 4.4.1-4
- rebuilt against openssl 0.9.8, neon 0.25.1
* Tue Jun 28 2005 Christian Metzen <metzench@ccux-linux.de> 4.4.1-3
- Fixed minor bug
* Tue Jun 28 2005 Christian Metzen <metzench@ccux-linux.de> 4.4.1-2
- Reverted Specfile to old behaviour, removed unneccessary foreign cripple
* Thu Jun 23 2005 Andreas Roth <aroth@arsoft-online.com> 4.4.1-1
- Version Update to 4.4.1
* Thu Feb 17 2005 Christian Metzen <metzench@ccux-linux.de> 4.4-3
- Fixed Minor Bug
* Thu Feb 17 2005 Christian Metzen <metzench@ccux-linux.de> 4.4-2
- Fixed some Dependencie Bugs
* Wed Feb 16 2005 Christian Metzen <metzench@ccux-linux.de> 4.4-1
- Version Update to 4.4
* Wed Apr 14 2004 Christian Metzen <metzench@ccux-linux.de> 4.2.1-2
- Initial Release
